static const char *const kEoB1ChargenStrings1DOSItalian[9] = {
	"Il tuo gruppo ""\x0E""\rcompleto.Premi il\rbottone GIOCA per\riniziare la nuova\rpartita.",
	"          ",
	"CA\rPF\rLIV",
	"%s\r%d\r%d\r%d\r%d\r%d",
	"%d\r%d",
	"%d",
	"%d/%d",
	"%d/%d/%d",
	"Scegli il riquadro\rdel personaggio\rche vuoi creare o\rvedere."
};

static const StringListProvider kEoB1ChargenStrings1DOSItalianProvider = { ARRAYSIZE(kEoB1ChargenStrings1DOSItalian), kEoB1ChargenStrings1DOSItalian };

static const char *const kEoB1ChargenStrings2DOSItalian[12] = {
	"%s",
	"%d",
	"%s",
	"%d",
	"%d",
	"%d",
	"%s",
	"%d",
	"SCEGLI RAZZA:",
	"SCEGLI CLASSE:",
	"SCEGLI ALLINEAMENTO:",
	"NOME:"
};

static const StringListProvider kEoB1ChargenStrings2DOSItalianProvider = { ARRAYSIZE(kEoB1ChargenStrings2DOSItalian), kEoB1ChargenStrings2DOSItalian };

static const char *const kEoB1ChargenStatStringsDOSItalian[12] = {
	"FOR",
	"INT",
	"SAG",
	"DES",
	"COS",
	"CAR",
	"FORZA",
	"INTELLIGENZA",
	"SAGGEZZA",
	"DESTREZZA",
	"COSTITUZIONE",
	"CARISMA"
};

static const StringListProvider kEoB1ChargenStatStringsDOSItalianProvider = { ARRAYSIZE(kEoB1ChargenStatStringsDOSItalian), kEoB1ChargenStatStringsDOSItalian };

static const char *const kEoB1ChargenRaceSexStringsDOSItalian[12] = {
	"UMANO MASCHIO",
	"UMANO FEMMINA",
	"ELFO MASCHIO",
	"ELFO FEMMINA",
	"MEZZUOMO MASCHIO",
	"MEZZUOMO FEMMINA",
	"NANO MASCHIO",
	"NANO FEMMINA",
	"GNOMO MASCHIO",
	"GNOMO FEMMINA",
	"MEZZUOMO MASCHIO",
	"MEZZUOMO FEMMINA"
};

static const StringListProvider kEoB1ChargenRaceSexStringsDOSItalianProvider = { ARRAYSIZE(kEoB1ChargenRaceSexStringsDOSItalian), kEoB1ChargenRaceSexStringsDOSItalian };

static const char *const kEoB1ChargenClassStringsDOSItalian[21] = {
	"GUERRIERO",
	"RANGER",
	"PALADINO",
	"MAGO",
	"CHIERICO",
	"LADRO",
	"GUERRIERO/CHIERICO",
	"GUERRIERO/LADRO",
	"GUERRIERO/MAGO",
	"GUER./MAGO/LADRO",
	"LADRO/MAGO",
	"CHIERICO/LADRO",
	"GUER./CHIERICO/MAGO",
	"RANGER/CHIERICO",
	"CHIERICO/MAGO",
	"GUERRIERO",
	"MAGO",
	"CHIERICO",
	"LADRO",
	"PALADINO",
	"RANGER"
};

static const StringListProvider kEoB1ChargenClassStringsDOSItalianProvider = { ARRAYSIZE(kEoB1ChargenClassStringsDOSItalian), kEoB1ChargenClassStringsDOSItalian };

static const char *const kEoB1ChargenAlignmentStringsDOSItalian[9] = {
	"LEGALE BUONO",
	"NEUTRALE BUONO",
	"CAOTICO BUONO",
	"LEGALE NEUTRALE",
	"NEUTRALE PURO",
	"CAOTICO NEUTRALE",
	"LEGALE MALVAGIO",
	"NEUTRALE MALVAGIO",
	"CAOTICO MALVAGIO"
};

static const StringListProvider kEoB1ChargenAlignmentStringsDOSItalianProvider = { ARRAYSIZE(kEoB1ChargenAlignmentStringsDOSItalian), kEoB1ChargenAlignmentStringsDOSItalian };

static const char *const kEoB1ChargenEnterGameStringsDOSItalian[1] = {
	"  Avvio partita.\r  in corso..."
};

static const StringListProvider kEoB1ChargenEnterGameStringsDOSItalianProvider = { ARRAYSIZE(kEoB1ChargenEnterGameStringsDOSItalian), kEoB1ChargenEnterGameStringsDOSItalian };

static const char *const kEoB1MainMenuStringsDOSItalian[3] = {
	"CARICA UNA PARTITA\r",
	"CREA UN NUOVO GRUPPO\r",
	"ESCI\r"
};

static const StringListProvider kEoB1MainMenuStringsDOSItalianProvider = { ARRAYSIZE(kEoB1MainMenuStringsDOSItalian), kEoB1MainMenuStringsDOSItalian };

static const char *const kEoB1BonusStringsDOSItalian[3] = {
	"Congratulazioni per aver scoperto tutte le 12 quest bonus di Beholder.\r\rI nomi dei personaggi del tuo gruppo vincente sono:\r\r",
	"\r",
	"\r\rPassword: %04x\r"
};

static const StringListProvider kEoB1BonusStringsDOSItalianProvider = { ARRAYSIZE(kEoB1BonusStringsDOSItalian), kEoB1BonusStringsDOSItalian };

static const char *const kEoB1TurnUndeadStringDOSItalian[1] = {
	"\x06\x06""%s usa scacciare non-morti!""\x06\x0F""\r"
};

static const StringListProvider kEoB1TurnUndeadStringDOSItalianProvider = { ARRAYSIZE(kEoB1TurnUndeadStringDOSItalian), kEoB1TurnUndeadStringDOSItalian };

static const char *const kEoB1Npc0StringsDOSItalian[2] = {
	"\rVi auguro fortuna nel vostro viaggio.",
	"Chi dovrei resuscitare?"
};

static const StringListProvider kEoB1Npc0StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc0StringsDOSItalian), kEoB1Npc0StringsDOSItalian };

static const char *const kEoB1Npc11StringsDOSItalian[3] = {
	"Curalo",
	"Parla",
	"Riparti"
};

static const StringListProvider kEoB1Npc11StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc11StringsDOSItalian), kEoB1Npc11StringsDOSItalian };

static const char *const kEoB1Npc12StringsDOSItalian[2] = {
	"Curalo",
	"Riparti"
};

static const StringListProvider kEoB1Npc12StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc12StringsDOSItalian), kEoB1Npc12StringsDOSItalian };

static const char *const kEoB1Npc21StringsDOSItalian[2] = {
	"Ascolta Proposta",
	"Riparti"
};

static const StringListProvider kEoB1Npc21StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc21StringsDOSItalian), kEoB1Npc21StringsDOSItalian };

static const char *const kEoB1Npc22StringsDOSItalian[2] = {
	"Aiutalo",
	"Riparti"
};

static const StringListProvider kEoB1Npc22StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc22StringsDOSItalian), kEoB1Npc22StringsDOSItalian };

static const char *const kEoB1Npc31StringsDOSItalian[2] = {
	"Cura Gruppo",
	"Riparti"
};

static const StringListProvider kEoB1Npc31StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc31StringsDOSItalian), kEoB1Npc31StringsDOSItalian };

static const char *const kEoB1Npc32StringsDOSItalian[3] = {
	"Cura Gruppo",
	"Resuscita morti",
	"Riparti"
};

static const StringListProvider kEoB1Npc32StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc32StringsDOSItalian), kEoB1Npc32StringsDOSItalian };

static const char *const kEoB1Npc4StringsDOSItalian[2] = {
	"Attacca",
	"Corrompi"
};

static const StringListProvider kEoB1Npc4StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc4StringsDOSItalian), kEoB1Npc4StringsDOSItalian };

static const char *const kEoB1Npc5StringsDOSItalian[3] = {
	"Uccidila",
	"Ascoltala",
	"Falla scappare"
};

static const StringListProvider kEoB1Npc5StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc5StringsDOSItalian), kEoB1Npc5StringsDOSItalian };

static const char *const kEoB1Npc6StringsDOSItalian[2] = {
	"Arrenditi",
	"Attacca"
};

static const StringListProvider kEoB1Npc6StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc6StringsDOSItalian), kEoB1Npc6StringsDOSItalian };

static const char *const kEoB1Npc7StringsDOSItalian[3] = {
	"Liberalo",
	"Uccidilo",
	"Riparti"
};

static const StringListProvider kEoB1Npc7StringsDOSItalianProvider = { ARRAYSIZE(kEoB1Npc7StringsDOSItalian), kEoB1Npc7StringsDOSItalian };

static const char *const kEoB1PryDoorStringsDOSItalian[7] = {
	"Nessuno pu""\x11"" forzare la porta\r",
	"Il gruppo forza la porta!\r",
	"%s forza la porta!\r",
	"Il gruppo prova a forzare la porta, ma fallisce.\r",
	"Non puoi metterci quest'oggetto.\r",
	"L'oggetto ""\x0E"" troppo grande.\r",
	"Nessuno pu""\x11"" forzare questa porta.\r"
};

static const StringListProvider kEoB1PryDoorStringsDOSItalianProvider = { ARRAYSIZE(kEoB1PryDoorStringsDOSItalian), kEoB1PryDoorStringsDOSItalian };

static const char *const kEoB1WarningStringsDOSItalian[3] = {
	"Non potete proseguire da questa parte.\r",
	"%s non pu""\x11"" consumare cibo!\r",
	"Non ""\x0E"" commestibile!\r"
};

static const StringListProvider kEoB1WarningStringsDOSItalianProvider = { ARRAYSIZE(kEoB1WarningStringsDOSItalian), kEoB1WarningStringsDOSItalian };

static const char *const kEoB1ItemSuffixStringsRingsDOSItalian[4] = {
	"Ornamento",
	"Stregoneria",
	"Sostentamento",
	"Caduta Morbida"
};

static const StringListProvider kEoB1ItemSuffixStringsRingsDOSItalianProvider = { ARRAYSIZE(kEoB1ItemSuffixStringsRingsDOSItalian), kEoB1ItemSuffixStringsRingsDOSItalian };

static const char *const kEoB1ItemSuffixStringsPotionsDOSItalian[8] = {
	"Forza dei Giganti",
	"Guarigione",
	"Super-Guarigione",
	"Veleno",
	"Vitalit""\x0C""",
	"Velocit""\x0C""",
	"Invisibilit""\x0C""",
	"Antidoti"
};

static const StringListProvider kEoB1ItemSuffixStringsPotionsDOSItalianProvider = { ARRAYSIZE(kEoB1ItemSuffixStringsPotionsDOSItalian), kEoB1ItemSuffixStringsPotionsDOSItalian };

static const char *const kEoB1ItemSuffixStringsWandsDOSItalian[7] = {
	"Legno",
	"Fulmini",
	"Gelo",
	"Cure",
	"Palla di Fuoco",
	"Silvias",
	"Dardo Incantato",
};

static const StringListProvider kEoB1ItemSuffixStringsWandsDOSItalianProvider = { ARRAYSIZE(kEoB1ItemSuffixStringsWandsDOSItalian), kEoB1ItemSuffixStringsWandsDOSItalian };

static const char *const kEoB1RipItemStringsDOSItalian[3] = {
	"%s ha perso la sua ",
	"%s ha perso il suo ",
	".\r"
};

static const StringListProvider kEoB1RipItemStringsDOSItalianProvider = { ARRAYSIZE(kEoB1RipItemStringsDOSItalian), kEoB1RipItemStringsDOSItalian };

static const char *const kEoB1CursedStringDOSItalian[1] = {
	"Maledetta %s %d"
};

static const StringListProvider kEoB1CursedStringDOSItalianProvider = { ARRAYSIZE(kEoB1CursedStringDOSItalian), kEoB1CursedStringDOSItalian };

static const char *const kEoB1MagicObjectStringsDOSItalian[5] = {
	"Pergamena del mago",
	"Pergamena del Chierico",
	"Anello",
	"Pozione",
	"Bacchetta"
};

static const StringListProvider kEoB1MagicObjectStringsDOSItalianProvider = { ARRAYSIZE(kEoB1MagicObjectStringsDOSItalian), kEoB1MagicObjectStringsDOSItalian };

static const char *const kEoB1MagicObjectString5DOSItalian[1] = {
	"Legno"
};

static const StringListProvider kEoB1MagicObjectString5DOSItalianProvider = { ARRAYSIZE(kEoB1MagicObjectString5DOSItalian), kEoB1MagicObjectString5DOSItalian };

static const char *const kEoB1PatternSuffixDOSItalian[1] = {
	"%s di %s"
};

static const StringListProvider kEoB1PatternSuffixDOSItalianProvider = { ARRAYSIZE(kEoB1PatternSuffixDOSItalian), kEoB1PatternSuffixDOSItalian };

static const char *const kEoB1PatternGrFix1DOSItalian[1] = {
	"%s di %s"
};

static const StringListProvider kEoB1PatternGrFix1DOSItalianProvider = { ARRAYSIZE(kEoB1PatternGrFix1DOSItalian), kEoB1PatternGrFix1DOSItalian };

static const char *const kEoB1PatternGrFix2DOSItalian[1] = {
	"%s di %s"
};

static const StringListProvider kEoB1PatternGrFix2DOSItalianProvider = { ARRAYSIZE(kEoB1PatternGrFix2DOSItalian), kEoB1PatternGrFix2DOSItalian };

static const char *const kEoB1ValidateArmorStringDOSItalian[1] = {
	"%s non pu""\x11"" indossare quest'armatura.\r"
};

static const StringListProvider kEoB1ValidateArmorStringDOSItalianProvider = { ARRAYSIZE(kEoB1ValidateArmorStringDOSItalian), kEoB1ValidateArmorStringDOSItalian };

static const char *const kEoB1ValidateNoDropStringDOSItalian[1] = {
	"Non puoi metterci quest'oggetto.\r"
};

static const StringListProvider kEoB1ValidateNoDropStringDOSItalianProvider = { ARRAYSIZE(kEoB1ValidateNoDropStringDOSItalian), kEoB1ValidateNoDropStringDOSItalian };

static const char *const kEoB1PotionStringsDOSItalian[2] = {
	"avvelenato",
	"%s si sente %s!\r"
};

static const StringListProvider kEoB1PotionStringsDOSItalianProvider = { ARRAYSIZE(kEoB1PotionStringsDOSItalian), kEoB1PotionStringsDOSItalian };

static const char *const kEoB1WandStringsDOSItalian[2] = {
	"La bacchetta pare priva di magia\r",
	"Nessun effetto.\r"
};

static const StringListProvider kEoB1WandStringsDOSItalianProvider = { ARRAYSIZE(kEoB1WandStringsDOSItalian), kEoB1WandStringsDOSItalian };

static const char *const kEoB1ItemMisuseStringsDOSItalian[3] = {
	"%s non pu""\x11"" usare quest'oggetto.\r",
	"Se indossato quest'oggetto funziona in automatico.\r",
	"Questo oggetto non si usa cos""\x10"".\r"
};

static const StringListProvider kEoB1ItemMisuseStringsDOSItalianProvider = { ARRAYSIZE(kEoB1ItemMisuseStringsDOSItalian), kEoB1ItemMisuseStringsDOSItalian };

static const char *const kEoB1TakenStringsDOSItalian[1] = {
	" preso.\r"
};

static const StringListProvider kEoB1TakenStringsDOSItalianProvider = { ARRAYSIZE(kEoB1TakenStringsDOSItalian), kEoB1TakenStringsDOSItalian };

static const char *const kEoB1PotionEffectStringsDOSItalian[8] = {
	"molto pi""\x12"" forte",
	"meglio",
	"molto meglio",
	"ammalato",
	"sazio",
	"agile e veloce",
	"trasparente",
	"meglio"
};

static const StringListProvider kEoB1PotionEffectStringsDOSItalianProvider = { ARRAYSIZE(kEoB1PotionEffectStringsDOSItalian), kEoB1PotionEffectStringsDOSItalian };

static const char *const kEoB1YesNoStringsDOSItalian[2] = {
	"s""\x10""",
	"no"
};

static const StringListProvider kEoB1YesNoStringsDOSItalianProvider = { ARRAYSIZE(kEoB1YesNoStringsDOSItalian), kEoB1YesNoStringsDOSItalian };

static const char *const kEoB1MoreStringsDOSItalian[1] = {
	" >> "
};

static const StringListProvider kEoB1MoreStringsDOSItalianProvider = { ARRAYSIZE(kEoB1MoreStringsDOSItalian), kEoB1MoreStringsDOSItalian };

static const char *const kEoB1NpcMaxStringsDOSItalian[1] = {
	"Puoi avere solo sei personaggi nel tuo gruppo.  Scegli chi congedare."
};

static const StringListProvider kEoB1NpcMaxStringsDOSItalianProvider = { ARRAYSIZE(kEoB1NpcMaxStringsDOSItalian), kEoB1NpcMaxStringsDOSItalian };

static const char *const kEoB1NpcJoinStringsDOSItalian[1] = {
	"%s si unisce al gruppo.\r"
};

static const StringListProvider kEoB1NpcJoinStringsDOSItalianProvider = { ARRAYSIZE(kEoB1NpcJoinStringsDOSItalian), kEoB1NpcJoinStringsDOSItalian };

static const char *const kEoB1CancelStringsDOSItalian[1] = {
	"ANNULLA"
};

static const StringListProvider kEoB1CancelStringsDOSItalianProvider = { ARRAYSIZE(kEoB1CancelStringsDOSItalian), kEoB1CancelStringsDOSItalian };

static const char *const kEoB1MenuStringsMainDOSItalian[8] = {
	"Opzioni:",
	"Riposa",
	"Studia Incantesimi",
	"Prega Incantesimi",
	"Trascrivi Pergamene",
	"Impostazioni",
	"Opzioni",
	" << "
};

static const StringListProvider kEoB1MenuStringsMainDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsMainDOSItalian), kEoB1MenuStringsMainDOSItalian };

static const char *const kEoB1MenuStringsSaveLoadDOSItalian[8] = {
	"Carica Partita",
	"Salva Partita",
	"Congeda Personaggio",
	"Esci dal gioco",
	"Opzioni:",
	"\r   Salvato!",
	"\r Salvataggio\r fallito!",
	"\r Caricamento\r fallito!"
};

static const StringListProvider kEoB1MenuStringsSaveLoadDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsSaveLoadDOSItalian), kEoB1MenuStringsSaveLoadDOSItalian };

static const char *const kEoB1MenuStringsOnOffDOSItalian[2] = {
	"ON",
	"OFF"
};

static const StringListProvider kEoB1MenuStringsOnOffDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsOnOffDOSItalian), kEoB1MenuStringsOnOffDOSItalian };

static const char *const kEoB1MenuStringsSpellsDOSItalian[17] = {
	"\r\r Scegli il\r personaggio del\r gruppo a cui\r far studiare gli\r incantesimi.",
	"\r Il tuo Paladino ""\x0E""\r di livello troppo\r basso.",
	"\r\r Il Mago non ha\r il Libro degli\r Incantesimi!",
	"\r\r\r Scegli il\r personaggio del\r gruppo a cui far\r pregare per gli\r incantesimi.",
	"\r Non hai nessun\r Chierico che\r possa pregare.",
	"\r Non hai nessun\r Mago che possa\r studiare gli\r incantesimi.",
	" Un Mago morto o\r svenuto non pu""\x11""\r memorizzare\r incantesimi.",
	" Un Chierico morto o\r svenuto non pu""\x11""\r memorizzare\r incantesimi.",
	"1",
	"2",
	"3",
	"4",
	"5",
	"Canc.",
	"Incantesimi:",
	"S""\x10""",
	"No"
};

static const StringListProvider kEoB1MenuStringsSpellsDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsSpellsDOSItalian), kEoB1MenuStringsSpellsDOSItalian };

static const char *const kEoB1MenuStringsRestDOSItalian[5] = {
	"\rMetti i tuoi \rguaritori a curare\ril gruppo?",
	" Qualcuno ""\x0E"" ancora\rferito. Riposa\rfino alla\rguarigione?",
	"Riposando.",
	"\r Tutti i\r personaggi sono\r riposati.",
	" Il tuo gruppo ha\rbisogno di riposare\rper ottenere gli\rincantesimi."
};

static const StringListProvider kEoB1MenuStringsRestDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsRestDOSItalian), kEoB1MenuStringsRestDOSItalian };

static const char *const kEoB1MenuStringsDropDOSItalian[1] = {
	" Non puoi avere\r meno di quattro\r personaggi."
};

static const StringListProvider kEoB1MenuStringsDropDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsDropDOSItalian), kEoB1MenuStringsDropDOSItalian };

static const char *const kEoB1MenuStringsExitDOSItalian[1] = {
	" Sei sicuro di\rvoler uscire dal\rgioco?"
};

static const StringListProvider kEoB1MenuStringsExitDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsExitDOSItalian), kEoB1MenuStringsExitDOSItalian };

static const char *const kEoB1MenuStringsStarveDOSItalian[1] = {
	" Il tuo gruppo sta\rpatendo la fame.\rContinua a riposare?"
};

static const StringListProvider kEoB1MenuStringsStarveDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsStarveDOSItalian), kEoB1MenuStringsStarveDOSItalian };

static const char *const kEoB1MenuStringsScribeDOSItalian[5] = {
	"Scegli la pergamena\rda trascrivere.",
	"\r\r\r Scegli un Mago che\r vorrebbe trascrivere\r gli incantesimi.",
	" Non hai nessuna\r pergamena da\r trascrivere.",
	" Non hai nessuna\r pergamena utile\r a questo Mago.",
	"\r Non hai nessun\r Mago che possa\r trascrivere\r pergamene."
};

static const StringListProvider kEoB1MenuStringsScribeDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsScribeDOSItalian), kEoB1MenuStringsScribeDOSItalian };

static const char *const kEoB1MenuStringsDrop2DOSItalian[3] = {
	" Scegli il\r personaggio da\r congedare.",
	" Sei sicuro di\rvoler salvare la\rpartita?",
	" Sei sicuro di\rvoler caricare una\rpartita?"
};

static const StringListProvider kEoB1MenuStringsDrop2DOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsDrop2DOSItalian), kEoB1MenuStringsDrop2DOSItalian };

static const char *const kEoB1MenuStringsHeadDOSItalian[3] = {
	"Al Campo:",
	"Impostazioni:",
	"Opzioni:"
};

static const StringListProvider kEoB1MenuStringsHeadDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsHeadDOSItalian), kEoB1MenuStringsHeadDOSItalian };

static const char *const kEoB1MenuStringsPoisonDOSItalian[1] = {
	"I membri avvelenati\rmoriranno! Riposa\rcomunque?"
};

static const StringListProvider kEoB1MenuStringsPoisonDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsPoisonDOSItalian), kEoB1MenuStringsPoisonDOSItalian };

static const char *const kEoB1MenuStringsMgcDOSItalian[2] = {
	"%-18s %1d",
	"%d di %d rimanenti.  "
};

static const StringListProvider kEoB1MenuStringsMgcDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsMgcDOSItalian), kEoB1MenuStringsMgcDOSItalian };

static const char *const kEoB1MenuStringsPrefsDOSItalian[4] = {
	"Musiche %-3s",
	"Effetti sonori %-3s",
	"Barre grafiche %-3s",
	"Mouse %-3s"
};

static const StringListProvider kEoB1MenuStringsPrefsDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsPrefsDOSItalian), kEoB1MenuStringsPrefsDOSItalian };

static const char *const kEoB1MenuStringsRest2DOSItalian[4] = {
	"%s ha ottenuto %s.\r",
	"%s ha memorizzato %s.\r",
	"%s Cura %s.\r",
	"Ore di riposo: %-4d"
};

static const StringListProvider kEoB1MenuStringsRest2DOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsRest2DOSItalian), kEoB1MenuStringsRest2DOSItalian };

static const char *const kEoB1MenuStringsRest4DOSItalian[1] = {
	"\rNon potete riposare vicino a dei mostri."
};

static const StringListProvider kEoB1MenuStringsRest4DOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsRest4DOSItalian), kEoB1MenuStringsRest4DOSItalian };

static const char *const kEoB1MenuStringsDefeatDOSItalian[1] = {
	"L'intero gruppo ""\x0E"" stato sconfitto.  I servitori del male potranno portare avanti i loro piani indisturbati!\r"
};

static const StringListProvider kEoB1MenuStringsDefeatDOSItalianProvider = { ARRAYSIZE(kEoB1MenuStringsDefeatDOSItalian), kEoB1MenuStringsDefeatDOSItalian };

static const char *const kEoB1MenuYesNoStringsDOSItalian[2] = {
	"S""\x10""",
	"No"
};

static const StringListProvider kEoB1MenuYesNoStringsDOSItalianProvider = { ARRAYSIZE(kEoB1MenuYesNoStringsDOSItalian), kEoB1MenuYesNoStringsDOSItalian };

static const char *const kEoB1CharGuiStringsHpDOSItalian[2] = {
	"PF",
	"%3d di %-3d"
};

static const StringListProvider kEoB1CharGuiStringsHpDOSItalianProvider = { ARRAYSIZE(kEoB1CharGuiStringsHpDOSItalian), kEoB1CharGuiStringsHpDOSItalian };

static const char *const kEoB1CharGuiStringsWp1DOSItalian[2] = {
	"FFSSS",
	"ZAC"
};

static const StringListProvider kEoB1CharGuiStringsWp1DOSItalianProvider = { ARRAYSIZE(kEoB1CharGuiStringsWp1DOSItalian), kEoB1CharGuiStringsWp1DOSItalian };

static const char *const kEoB1CharGuiStringsWrDOSItalian[4] = {
	"FUORI",
	"TIRO",
	"NESSUNA",
	"MUNIZIONE"
};

static const StringListProvider kEoB1CharGuiStringsWrDOSItalianProvider = { ARRAYSIZE(kEoB1CharGuiStringsWrDOSItalian), kEoB1CharGuiStringsWrDOSItalian };

static const char *const kEoB1CharGuiStringsSt1DOSItalian[6] = {
	"Scambiando",
	"MORTO",
	"SVENUTO",
	"(LENTEZZA)",
	"AVVELENATO",
	"PARALIZZATO"
};

static const StringListProvider kEoB1CharGuiStringsSt1DOSItalianProvider = { ARRAYSIZE(kEoB1CharGuiStringsSt1DOSItalian), kEoB1CharGuiStringsSt1DOSItalian };

static const char *const kEoB1CharGuiStringsInDOSItalian[4] = {
	"INFO EROE",
	"CLASSE ARMATURA",
	"ESP",
	"LIV"
};

static const StringListProvider kEoB1CharGuiStringsInDOSItalianProvider = { ARRAYSIZE(kEoB1CharGuiStringsInDOSItalian), kEoB1CharGuiStringsInDOSItalian };

static const char *const kEoB1CharStatusStrings7DOSItalian[1] = {
	"%s ha perso la forza dei giganti.\r"
};

static const StringListProvider kEoB1CharStatusStrings7DOSItalianProvider = { ARRAYSIZE(kEoB1CharStatusStrings7DOSItalian), kEoB1CharStatusStrings7DOSItalian };

static const char *const kEoB1CharStatusStrings81DOSItalian[1] = {
	"%s risente degli effetti del veleno!\r"
};

static const StringListProvider kEoB1CharStatusStrings81DOSItalianProvider = { ARRAYSIZE(kEoB1CharStatusStrings81DOSItalian), kEoB1CharStatusStrings81DOSItalian };

static const char *const kEoB1CharStatusStrings9DOSItalian[1] = {
	"%s non ""\x0E"" pi""\x12"" paralizzato!\r"
};

static const StringListProvider kEoB1CharStatusStrings9DOSItalianProvider = { ARRAYSIZE(kEoB1CharStatusStrings9DOSItalian), kEoB1CharStatusStrings9DOSItalian };

static const char *const kEoB1CharStatusStrings131DOSItalian[1] = {
	"%s ""\x0E"" %s!\r"
};

static const StringListProvider kEoB1CharStatusStrings131DOSItalianProvider = { ARRAYSIZE(kEoB1CharStatusStrings131DOSItalian), kEoB1CharStatusStrings131DOSItalian };

static const char *const kEoB1LevelGainStringsDOSItalian[1] = {
	"\x06\x01""%s ha guadagnato un livello di esperienza.""\x06\x0F""\r"
};

static const StringListProvider kEoB1LevelGainStringsDOSItalianProvider = { ARRAYSIZE(kEoB1LevelGainStringsDOSItalian), kEoB1LevelGainStringsDOSItalian };

static const char *const kEoB1BookNumbersDOSItalian[5] = {
	"Primo",
	"Secondo",
	"Terzo",
	"Quarto",
	"Quinto"
};

static const StringListProvider kEoB1BookNumbersDOSItalianProvider = { ARRAYSIZE(kEoB1BookNumbersDOSItalian), kEoB1BookNumbersDOSItalian };

static const char *const kEoB1MageSpellsListDOSItalian[26] = {
	"",
	"Armatura",
	"Mani Brucianti",
	"Individua Magico",
	"Dardo Incantato",
	"Lettura Magico",
	"Scudo",
	"Scarica Elettrica",
	"Invisibilit""\x0C",
	"Chiavistello",
	"Freccia Acida M.",
	"Nube Maleodorante",
	"Dissolvi Magie",
	"Palla di Fuoco",
	"Freccia Infuocata",
	"Velocit""\x0C",
	"Blocca Persone",
	"Invisibilit""\x0C"" 3m",
	"Fulmine",
	"Tocco del Vampiro",
	"Paura",
	"Tempesta Ghiaccio",
	"Pelle di Pietra",
	"Nube Assassina",
	"Cono di Freddo",
	"Blocca Mostri"
};

static const StringListProvider kEoB1MageSpellsListDOSItalianProvider = { ARRAYSIZE(kEoB1MageSpellsListDOSItalian), kEoB1MageSpellsListDOSItalian };

static const char *const kEoB1ClericSpellsListDOSItalian[25] = {
	"",
	"Benedizione",
	"Cura Ferite L.",
	"Causa Ferite L.",
	"Individua Magico",
	"Protezione dal Male",
	"Aiuto",
	"Lama Fiammeggiante",
	"Blocca Persone",
	"Rallenta Veleno",
	"Creare Cibo",
	"Dissolvi Magie",
	"Paramenti Magici",
	"Preghiera",
	"Rimuovi Paralisi",
	"Cura Ferite G.",
	"Causa Ferite G.",
	"Neutralizza Veleni",
	"Protezione Male 3m",
	"Protezione Fulmine",
	"Cura Ferite C.",
	"Causa Ferite C.",
	"Colonna di Fuoco",
	"Rianimare Morti",
	"Imposizione Mani"
};

static const StringListProvider kEoB1ClericSpellsListDOSItalianProvider = { ARRAYSIZE(kEoB1ClericSpellsListDOSItalian), kEoB1ClericSpellsListDOSItalian };

static const char *const kEoB1SpellNamesDOSItalian[51] = {
	"",
	"armatura",
	"mani brucianti",
	"individuazione del magico",
	"dardo incantato",
	"scudo",
	"scarica elettrica",
	"invisibilit""\x0C",
	"freccia acida di melf",
	"nube maleodorante",
	"dissolvi magie",
	"palla di fuoco",
	"freccia infuocata",
	"velocit""\x0C",
	"blocca persone",
	"invisibilit""\x0C"",raggio 3m",
	"fulmine",
	"tocco del vampiro",
	"paura",
	"tempesta di ghiaccio",
	"pelle di pietra",
	"nube assassina",
	"cono di freddo",
	"blocca mostri",
	"benedizione",
	"cura ferite leggere",
	"causa ferita leggere",
	"individuazione del magico",
	"protezione dal male",
	"aiuto",
	"lama fiammeggiante",
	"blocca persone",
	"rallenta veleno",
	"creare cibo e acqua",
	"dissolvi magie",
	"paramenti magici",
	"preghiera",
	"rimuovi paralisi",
	"cura ferite gravi",
	"causa ferite gravi",
	"neutralizzare veleni",
	"protezione dal male,raggio 3m",
	"protezione dal fulmine",
	"cura ferite critiche",
	"causa ferite critiche",
	"colonna di fuoco",
	"rianimare morti",
	"imposizione delle mani",
	"",
	"",
	""
};

static const StringListProvider kEoB1SpellNamesDOSItalianProvider = { ARRAYSIZE(kEoB1SpellNamesDOSItalian), kEoB1SpellNamesDOSItalian };

static const char *const kEoB1MagicStrings1DOSItalian[6] = {
	"ANNULLA",
	"ANNULLA",
	"Questo incantesimo richiede una mano libera.\r",
	"Non puoi avere due di questi incantesimi attivi.\r",
	"%s lancia %s.\r",
	"ok\r"
};

static const StringListProvider kEoB1MagicStrings1DOSItalianProvider = { ARRAYSIZE(kEoB1MagicStrings1DOSItalian), kEoB1MagicStrings1DOSItalian };

static const char *const kEoB1MagicStrings2DOSItalian[3] = {
	"nessun effetto\r",
	"%s ""\x0E"" stato disintegrato!!\r",
	"Il gruppo ""\x0E"" stato colpito da 'Morte'!\r"
};

static const StringListProvider kEoB1MagicStrings2DOSItalianProvider = { ARRAYSIZE(kEoB1MagicStrings2DOSItalian), kEoB1MagicStrings2DOSItalian };

static const char *const kEoB1MagicStrings3DOSItalian[6] = {
	"Su chi lanci l'incantesimo? ",
	"\rok\r",
	"\rAnnullato.\r",
	"L'incantesimo di %s, %s svanisce.\r",
	"%s ha mancato il mostro.\r",
	"%s deve stare in prima linea per colpire!\r"
};

static const StringListProvider kEoB1MagicStrings3DOSItalianProvider = { ARRAYSIZE(kEoB1MagicStrings3DOSItalian), kEoB1MagicStrings3DOSItalian };

static const char *const kEoB1MagicStrings4DOSItalian[1] = {
	"nessun effetto.\r"
};

static const StringListProvider kEoB1MagicStrings4DOSItalianProvider = { ARRAYSIZE(kEoB1MagicStrings4DOSItalian), kEoB1MagicStrings4DOSItalian };

static const char *const kEoB1MagicStrings6DOSItalian[1] = {
	"%s ha gi""\x0C"" classe armatura base alta.\r"
};

static const StringListProvider kEoB1MagicStrings6DOSItalianProvider = { ARRAYSIZE(kEoB1MagicStrings6DOSItalian), kEoB1MagicStrings6DOSItalian };

static const char *const kEoB1MagicStrings7DOSItalian[5] = {
	"I",
	"II",
	"III",
	"IV",
	"V"
};

static const StringListProvider kEoB1MagicStrings7DOSItalianProvider = { ARRAYSIZE(kEoB1MagicStrings7DOSItalian), kEoB1MagicStrings7DOSItalian };

static const char *const kEoB1MagicStrings8DOSItalian[3] = {
	"Tutti gli incantesimi su %s si sono dissolti.\r",
	"'Benedizione' ""\x0E"" gi""\x0C"" attiva sul gruppo.\r",
	"'Aiuto' fallisce!\r"
};

static const StringListProvider kEoB1MagicStrings8DOSItalianProvider = { ARRAYSIZE(kEoB1MagicStrings8DOSItalian), kEoB1MagicStrings8DOSItalian };
/*
static const char *const kEoB1MagicStrings9DOSItalian[1] = {
	"%s e gia protetto da pelle di pietra.\r"
};

static const StringListProvider kEoB1MagicStrings9DOSItalianProvider = { ARRAYSIZE(kEoB1MagicStrings9DOSItalian), kEoB1MagicStrings9DOSItalian };
*/
static const byte kEoB1ManDefDOSItalian[120] = {
	0x09, 0x0A, 0x02, 0x00, 0x09, 0x04, 0x03, 0x00,
	0x09, 0x06, 0x06, 0x00, 0x09, 0x03, 0x03, 0x00,
	0x09, 0x04, 0x02, 0x00, 0x09, 0x01, 0x02, 0x00,
	0x09, 0x05, 0x01, 0x00, 0x09, 0x09, 0x02, 0x00,
	0x09, 0x06, 0x02, 0x00, 0x23, 0x01, 0x05, 0x00,
	0x23, 0x02, 0x02, 0x00, 0x23, 0x03, 0x06, 0x00,
	0x23, 0x05, 0x01, 0x00, 0x23, 0x06, 0x03, 0x00,
	0x23, 0x07, 0x01, 0x00, 0x1A, 0x01, 0x01, 0x00,
	0x1A, 0x03, 0x02, 0x00, 0x1A, 0x06, 0x01, 0x00,
	0x24, 0x01, 0x03, 0x00, 0x24, 0x03, 0x04, 0x00,
	0x24, 0x03, 0x01, 0x00, 0x02, 0x04, 0x03, 0x00,
	0x02, 0x03, 0x03, 0x00, 0x02, 0x05, 0x03, 0x00,
	0x01, 0x01, 0x01, 0x00, 0x01, 0x05, 0x03, 0x00,
	0x01, 0x04, 0x03, 0x00, 0x0C, 0x02, 0x01, 0x00,
	0x0C, 0x03, 0x03, 0x00, 0x0C, 0x04, 0x02, 0x00
};

static const ByteProvider kEoB1ManDefDOSItalianProvider = { ARRAYSIZE(kEoB1ManDefDOSItalian), kEoB1ManDefDOSItalian };

static const char *const kEoB1ManWordDOSItalian[31] = {
	"attacks",
	"short",
	"line",
	"weapons",
	"certain",
	"rank",
	"rear",
	"can",
	"away",
	"dungeon",
	"cursor",
	"feature",
	"information",
	"displayed",
	"below",
	"around",
	"carefree",
	"gnomes",
	"clerics",
	"mystic",
	"pummel",
	"fitness",
	"using",
	"toughness",
	"wealth",
	"wizard",
	"officials",
	"hound",
	"disturbing",
	"flaming",
	""
};

static const StringListProvider kEoB1ManWordDOSItalianProvider = { ARRAYSIZE(kEoB1ManWordDOSItalian), kEoB1ManWordDOSItalian };

static const char *const kEoB1ManPromptDOSItalian[1] = {
	"\r\r\r\rOn the page with this symbol...\r\rFind line %d\rEnter word %d\r"
};

static const StringListProvider kEoB1ManPromptDOSItalianProvider = { ARRAYSIZE(kEoB1ManPromptDOSItalian), kEoB1ManPromptDOSItalian };

static const char *const kEoB1MonsterDistAttStringsDOSItalian[5] = {
	"%s ""\x0E"" stato colpito da 'Causa Ferite Gravi'\r",
	"Il gruppo ""\x0E"" stato colpito da 'Flagello Mentale'!\r",
	"paralizzato",
	"avvelenato",
	"paralizzato"
};

static const StringListProvider kEoB1MonsterDistAttStringsDOSItalianProvider = { ARRAYSIZE(kEoB1MonsterDistAttStringsDOSItalian), kEoB1MonsterDistAttStringsDOSItalian };

static const char *const kEoB1NpcPresetsNamesDOSItalian[9] = {
	"Anya",
	"Beohram",
	"Kirath",
	"Ileria",
	"Tyrra",
	"Tod Uphill",
	"Taghor",
	"Dohrum",
	"Keirgar"
};

static const StringListProvider kEoB1NpcPresetsNamesDOSItalianProvider = { ARRAYSIZE(kEoB1NpcPresetsNamesDOSItalian), kEoB1NpcPresetsNamesDOSItalian };
